pub struct Temporal;Expand description
The Temporal object for accessing current system time
Implementations
Sourceimpl Temporal
impl Temporal
Sourcepub fn now() -> Now<LocalHostSystem>
👎Deprecated since 0.1.0: now deprecated was not clear about the host system implementation, please use local_now
pub fn now() -> Now<LocalHostSystem>
now deprecated was not clear about the host system implementation, please use local_now
Get a Now object for the default host system.
Sourcepub fn local_now() -> Now<LocalHostSystem>
pub fn local_now() -> Now<LocalHostSystem>
Get a Now object with a LocalHostSystem, which
will use the host system’s time zone as a fallback.
Sourcepub fn utc_now() -> Now<UtcHostSystem>
pub fn utc_now() -> Now<UtcHostSystem>
Get a Now object with a UtcHostSystem, which
will use a UTC time zone as a fallback.